nanite
======

|PyPI Version| |Build Status| |Coverage Status| |Docs Status|

Loading, fitting, and rating AFM force-distance data.

Documentation
-------------

The documentation, including the code reference and examples, is available at
`nanite.readthedocs.io <https://nanite.readthedocs.io/en/stable/>`__.


Installation
------------
To install the latest release, simply run:

::

    pip install nanite[CLI]


.. |PyPI Version| image:: https://img.shields.io/pypi/v/nanite.svg
   :target: https://pypi.python.org/pypi/nanite
.. |Build Status| image:: https://img.shields.io/github/actions/workflow/status/AFM-analysis/nanite/check.yml
   :target: https://github.com/AFM-analysis/nanite/actions?query=workflow%3AChecks
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/AFM-analysis/nanite/master.svg
   :target: https://codecov.io/gh/AFM-analysis/nanite
.. |Docs Status| image:: https://readthedocs.org/projects/nanite/badge/?version=latest
   :target: https://readthedocs.org/projects/nanite/builds/
